@@ -9,7 +9,7 @@ from sybil.document import Document, PythonDocStringDocument
 from sybil.example import SybilFailure
 from sybil.parsers.abstract import DocTestStringParser
 from sybil.parsers.rest import DocTestParser, DocTestDirectiveParser
-from .helpers import sample_path, parse, FUNCTIONAL_TEST_DIR, skip_if_37_or_older
+from .helpers import sample_path, parse, FUNCTIONAL_TEST_DIR
 
 
 def test_pass():
@@ -131,7 +131,6 @@ UNPARSEABLE = {
 MINIMUM_EXPECTED_DOCTESTS = 9
 
 
-@skip_if_37_or_older()
 def test_sybil_example_count(all_python_files):
     parser = DocTestStringParser()
 
@@ -149,7 +148,6 @@ def test_sybil_example_count(all_python_files):
 
 
 def check_sybil_against_doctest(path, text):
-    skip_if_37_or_older()
     problems = []
     name = str(path)
     regions = list(DocTestStringParser()(text, path))
@@ -163,8 +161,14 @@ def check_sybil_against_doctest(path, text):
         region_source = text[region.start:region.end]
         for name in 'source', 'want':
             expected = getattr(example, name)
-            if expected not in region_source:  # pragma: no cover - Only on failures!
-                problems.append(f'{region}:{name}\n{expected!r} not in {region_source!r}')
+            if name == 'source':
+                # doctest.DocTestParser REPL examples are pre-processed into python
+                # source to execute, so do similar here but note this is pretty fragile:
+                expected_source = region_source.replace('>>>', '').replace('    ... ', '')
+            else:
+                expected_source = region_source
+            if expected not in expected_source:  # pragma: no cover - Only on failures!
+                problems.append(f'{region}:{name}\n{expected!r} not in {expected_source!r}')
     problems = [problem for problem in problems if problem]
     if problems:  # pragma: no cover - Only on failures!
         raise AssertionError('doctests not correctly extracted:\n\n'+'\n\n'.join(problems))
@@ -177,7 +181,6 @@ def test_all_docstest_examples_extracted_from_source_correctly(python_file):
     check_sybil_against_doctest(path, source)
 
 
-@skip_if_37_or_older()
 def test_all_docstest_examples_extracted_from_docstrings_correctly(python_file):
     path, source = python_file
     for start, end, docstring in PythonDocStringDocument.extract_docstrings(source):
